# import keyboard and augmenters
from .da import (
    create_qwerty_da,
    create_da_æøå_replace_augmenter,
    create_da_historical_noun_casing_augmenter,
)
from .de import create_qwerty_de
from .el import create_qwerty_el
from .en import create_qwerty_en
from .es import create_qwerty_es
from .fr import create_qwerty_fr
from .it import create_qwerty_it
from .lt import create_qwerty_lt
from .mk import create_mk
from .nb import create_qwerty_nb
from .nl import create_qwerty_nl
from .pl import create_qwerty_pl
from .pt import create_qwerty_pt
from .ro import create_qwerty_ro
from .ru import create_ru
